[CCCL] 瘦身 + 补全: 移除 cudax/python/libcudacxx-tests 冗余文件, 新增 c2h 测试助手 + cmake 构建系统 + 8 个 CUDA thrust examples
变更摘要:
- 删除: cudax/ (783 files, 7.2M) — 实验性组件,竞赛不需要
- 删除: python/ (226 files, 2.0M) — Python 绑定,竞赛不需要
- 删除: libcudacxx/{test,benchmarks,codegen,cmake,share} (4432 files, 31M)
保留: libcudacxx/include/ (1463 headers, cuda::std 编译依赖)
- 新增: c2h/ (27 files) — CUB Catch2 测试辅助头文件,编译 243 个测试必需
- 新增: cmake/ (29 files) — CCCL 原生 CMake 构建系统
- 新增: thrust/examples/cuda/ (7 files) + cpp_integration/ (1 file)
async_reduce, custom_temporary_allocation, explicit_cuda_stream,
global_device_vector, range_view, unwrap_pointer, wrap_pointer, device
结果: cccl_upstream 从 74M→35M (瘦身 53%), 核心内容 100% 保留:
27/27 tuning headers, 78 benchmarks, 243 tests,
60 thrust examples, 18 CUB examples, 全部编译头文件
This commit is contained in:
@@ -1,95 +0,0 @@
|
||||
//===----------------------------------------------------------------------===//
|
||||
//
|
||||
// Part of CUDASTF in CUDA C++ Core Libraries,
|
||||
// under the Apache License v2.0 with LLVM Exceptions.
|
||||
// See https://llvm.org/LICENSE.txt for license information.
|
||||
// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
|
||||
// SPDX-FileCopyrightText: Copyright (c) 2022-2024 NVIDIA CORPORATION & AFFILIATES.
|
||||
//
|
||||
//===----------------------------------------------------------------------===//
|
||||
|
||||
/**
|
||||
* @file
|
||||
* @brief Example of reduction implementing using CUB kernels
|
||||
*/
|
||||
|
||||
#include <thrust/device_vector.h>
|
||||
|
||||
#include <cuda/experimental/stf.cuh>
|
||||
|
||||
using namespace cuda::experimental::stf;
|
||||
|
||||
template <int BLOCK_THREADS, typename T>
|
||||
__global__ void reduce(slice<const T> values, slice<T> partials, size_t nelems)
|
||||
{
|
||||
using namespace cub;
|
||||
typedef BlockReduce<T, BLOCK_THREADS> BlockReduceT;
|
||||
|
||||
auto thread_id = BLOCK_THREADS * blockIdx.x + threadIdx.x;
|
||||
|
||||
// Local reduction
|
||||
T local_sum = 0;
|
||||
for (size_t ind = thread_id; ind < nelems; ind += blockDim.x * gridDim.x)
|
||||
{
|
||||
local_sum += values(ind);
|
||||
}
|
||||
|
||||
__shared__ typename BlockReduceT::TempStorage temp_storage;
|
||||
|
||||
// Per-thread tile data
|
||||
T result = BlockReduceT(temp_storage).Sum(local_sum);
|
||||
|
||||
if (threadIdx.x == 0)
|
||||
{
|
||||
partials(blockIdx.x) = result;
|
||||
}
|
||||
}
|
||||
|
||||
template <typename Ctx>
|
||||
void run()
|
||||
{
|
||||
Ctx ctx;
|
||||
|
||||
const size_t N = 1024 * 16;
|
||||
const size_t BLOCK_SIZE = 128;
|
||||
const size_t num_blocks = 32;
|
||||
|
||||
int *X, ref_tot;
|
||||
|
||||
X = new int[N];
|
||||
ref_tot = 0;
|
||||
|
||||
for (size_t ind = 0; ind < N; ind++)
|
||||
{
|
||||
X[ind] = rand() % N;
|
||||
ref_tot += X[ind];
|
||||
}
|
||||
|
||||
auto values = ctx.logical_data(X, {N});
|
||||
auto partials = ctx.logical_data(shape_of<slice<int>>(num_blocks));
|
||||
auto result = ctx.logical_data(shape_of<slice<int>>(1));
|
||||
|
||||
ctx.task(values.read(), partials.write(), result.write())->*[&](auto stream, auto values, auto partials, auto result) {
|
||||
// reduce values into partials
|
||||
reduce<BLOCK_SIZE, int><<<num_blocks, BLOCK_SIZE, 0, stream>>>(values, partials, N);
|
||||
|
||||
// reduce partials on a single block into result
|
||||
reduce<BLOCK_SIZE, int><<<1, BLOCK_SIZE, 0, stream>>>(partials, result, num_blocks);
|
||||
};
|
||||
|
||||
ctx.host_launch(result.read())->*[&](auto p) {
|
||||
if (p(0) != ref_tot)
|
||||
{
|
||||
fprintf(stderr, "INCORRECT RESULT: p sum = %d, ref tot = %d\n", p(0), ref_tot);
|
||||
abort();
|
||||
}
|
||||
};
|
||||
|
||||
ctx.finalize();
|
||||
}
|
||||
|
||||
int main()
|
||||
{
|
||||
run<stream_ctx>();
|
||||
run<graph_ctx>();
|
||||
}
|
||||
Reference in New Issue
Block a user